<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr" sourcelanguage="en">
<context>
    <name>ConvertToSQLiteDialog</name>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="26"/>
        <source>Import BAM File</source>
        <translation>BAM Dosyasını İçe Aktar</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="34"/>
        <source>Source URL:</source>
        <translation>Kaynak URL:</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="48"/>
        <source>Info</source>
        <translation>Bilgi</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="55"/>
        <source>Reference:</source>
        <translation>Referans:</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="69"/>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="193"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="84"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;left&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Input SAM file does not contain a header. Сhoose a file with reference sequences or references info will be generated.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;left&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Giriş SAM dosyası başlık içermiyor. Referans dizileri içeren bir dosya seçin veya referans bilgileri oluşturulacaktır.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="98"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;left&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Index file (*.bai) is not available. Partial import is going to be slowed down.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;left&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Dizin dosyası (* .bai) mevcut değil. Kısmi ithalat yavaşlayacak.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="137"/>
        <source>Select All</source>
        <translation>Tümünü Seç</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="144"/>
        <source>Deselect All</source>
        <translation>Tüm Seçimi Kaldır</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="151"/>
        <source>Invert Selection</source>
        <translation>Seçimi Tersine Çevir</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="174"/>
        <source>Import unmapped reads</source>
        <translation>Eşlenmemiş okumaları içe aktar</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="183"/>
        <source>Destination URL:</source>
        <translation>Hedef URL:</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="204"/>
        <source>Add to project</source>
        <translation>Projeye ekle</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;The SAM file does not contain the header. Please, choose the reference sequence.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;SAM dosyası başlık içermiyor. Lütfen referans sırasını seçin.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Index file (*.bai) is not available. Partial import is going to be slowed down.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Dizin dosyası (*.bai) mevcut değil. Kısmi ithalat yavaşlayacak.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="247"/>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="250"/>
        <source>Reference File</source>
        <translation>Referans Dosyası</translation>
    </message>
</context>
<context>
    <name>U2::BAM::BAMDbiPlugin</name>
    <message>
        <location filename="../src/BaiReader.cpp" line="43"/>
        <location filename="../src/Reader.cpp" line="433"/>
        <source>Invalid magic number</source>
        <translation>Geçersiz sihirli numara</translation>
    </message>
    <message>
        <location filename="../src/BaiReader.cpp" line="48"/>
        <location filename="../src/Reader.cpp" line="448"/>
        <source>Invalid number of references: %1</source>
        <translation>Geçersiz referans sayısı: %1</translation>
    </message>
    <message>
        <location filename="../src/BaiReader.cpp" line="54"/>
        <source>Invalid number of bins: %1</source>
        <translation>Geçersiz bölme sayısı: %1</translation>
    </message>
    <message>
        <location filename="../src/BaiReader.cpp" line="61"/>
        <source>Invalid number of chunks: %1</source>
        <translation>Geçersiz parça sayısı: %1</translation>
    </message>
    <message>
        <location filename="../src/BaiReader.cpp" line="79"/>
        <source>Invalid number of intervals: %1</source>
        <translation>Geçersiz aralık sayısı: %1</translation>
    </message>
    <message>
        <location filename="../src/BaiReader.cpp" line="94"/>
        <source>Can&apos;t read input. %1</source>
        <translation>Giriş okunamıyor. %1</translation>
    </message>
    <message>
        <location filename="../src/BaiReader.cpp" line="96"/>
        <location filename="../src/BgzfReader.cpp" line="121"/>
        <location filename="../src/BgzfReader.cpp" line="143"/>
        <location filename="../src/Reader.cpp" line="350"/>
        <source>Unexpected end of file</source>
        <translation>Beklenmedik dosya sonlandırması</translation>
    </message>
    <message>
        <location filename="../src/BaiWriter.cpp" line="59"/>
        <location filename="../src/BgzfWriter.cpp" line="74"/>
        <location filename="../src/BgzfWriter.cpp" line="106"/>
        <source>Can&apos;t write output</source>
        <translation>Çıktı yazılamıyor</translation>
    </message>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="73"/>
        <source>BAM format support</source>
        <translation>BAM format desteği</translation>
    </message>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="73"/>
        <source>Interface for indexed read-only access to BAM files</source>
        <translation>BAM dosyalarına endekslenmiş salt okunur erişim için arayüz</translation>
    </message>
    <message>
        <location filename="../src/BgzfReader.cpp" line="43"/>
        <location filename="../src/BgzfWriter.cpp" line="43"/>
        <source>Can&apos;t initialize zlib</source>
        <translation>Zlib başlatılamıyor</translation>
    </message>
    <message>
        <location filename="../src/BgzfReader.cpp" line="65"/>
        <location filename="../src/BgzfReader.cpp" line="130"/>
        <location filename="../src/BgzfReader.cpp" line="160"/>
        <source>Can&apos;t read input</source>
        <translation>Giriş okunamıyor</translation>
    </message>
    <message>
        <location filename="../src/BgzfReader.cpp" line="81"/>
        <location filename="../src/BgzfReader.cpp" line="179"/>
        <source>Can&apos;t decompress data</source>
        <translation>Verileri açamıyorum</translation>
    </message>
    <message>
        <location filename="../src/BgzfWriter.cpp" line="70"/>
        <location filename="../src/BgzfWriter.cpp" line="112"/>
        <source>Can&apos;t compress data</source>
        <translation>Veriler sıkıştırılamıyor</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="26"/>
        <source>Hard clip in the middle of cigar</source>
        <translation>Puronun ortasında sert klips</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="36"/>
        <source>Misplaced soft clip in the cigar: must be preceded with hard clip</source>
        <translation>Puroda yanlış yerleştirilmiş yumuşak klips: önünde sert klips bulunmalıdır</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="40"/>
        <source>Misplaced soft clip in the cigar: must be succeeded with hard clip</source>
        <translation>Puroda yanlış yerleştirilmiş yumuşak klips: sert klipsle başarılı olunmalıdır</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="43"/>
        <source>Misplaced soft clip in the cigar: can&apos;t be in the middle of the string</source>
        <translation>Puroda yanlış yerleştirilmiş yumuşak klips: ipin ortasında olamaz</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="65"/>
        <source>No match or skip operation between adjacent in/del/skip operations</source>
        <translation>Bitişik içeri / sil / atlama işlemleri arasında eşleşme veya atlama işlemi yok</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="72"/>
        <source>CIGAR can&apos;t start or end with padding operator</source>
        <translation>CIGAR dolgu operatörüyle başlayamaz veya bitemez</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="74"/>
        <source>Padding operator must be located between real operations</source>
        <translation>Dolgu operatörü gerçek operasyonlar arasında konumlandırılmalıdır</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="93"/>
        <source>CIGAR must contain at least one real operation (ins/del/match/skip)</source>
        <translation>CIGAR en az bir gerçek işlem içermelidir (ins/sil/eşleşme/atla)</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="82"/>
        <source>Assembly name</source>
        <translation>Montaj adı</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="82"/>
        <source>Length</source>
        <translation>Uzunluk</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="82"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="146"/>
        <source>%1 file info</source>
        <translation>%1 dosya bilgisi</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="152"/>
        <source>Property name</source>
        <translation>Özellik adı</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="152"/>
        <source>Value</source>
        <translation>Değer</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="159"/>
        <source>Unsorted</source>
        <translation>Sınıflandırılmamış</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="160"/>
        <source>Unknown</source>
        <translation>Bilinmeyen</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="161"/>
        <source>Coordinate</source>
        <translation>Koordinat</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="162"/>
        <source>Query name</source>
        <translation>Sorgu adı</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="165"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="166"/>
        <source>Format version</source>
        <translation>Versiyonu biçimlendir</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="167"/>
        <source>Sorting order</source>
        <translation>Sıralama düzeni</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="187"/>
        <source>Sequencing center</source>
        <translation>Sıralama merkezi</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="187"/>
        <source>Description</source>
        <translation>Açıklama</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="187"/>
        <source>Date</source>
        <translation>Tarih</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="188"/>
        <source>Library</source>
        <translation>Kitaplık</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="188"/>
        <source>Programs</source>
        <translation>Programlar</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="188"/>
        <source>Predicted median insert size</source>
        <translation>Öngörülen medyan kesici uç boyutu</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="188"/>
        <source>Platform/technology</source>
        <translation>Platform / teknoloji</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="189"/>
        <source>Platform unit</source>
        <translation>Platform ünitesi</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="189"/>
        <source>Sample</source>
        <translation>Örnek</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="206"/>
        <source>Read groups:</source>
        <translation>Grupları okuyun:</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="213"/>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="213"/>
        <source>Version</source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="213"/>
        <source>Command</source>
        <translation>Komut</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="213"/>
        <source>Previous ID</source>
        <translation>Önceki kimlik</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="229"/>
        <source>Programs:</source>
        <translation>Programlar:</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="293"/>
        <source>Please select assemblies to be imported</source>
        <translation>Lütfen içe aktarılacak montajları seçin</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="316"/>
        <source>Destination URL is not specified</source>
        <translation>Hedef URL belirtilmedi</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="319"/>
        <source>Destination URL must point to a local file</source>
        <translation>Hedef URL yerel bir dosyaya işaret etmelidir</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="322"/>
        <source>Destination URL folder has not write permissions</source>
        <translation>Hedef URL klasörünün yazma izinleri yok</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="332"/>
        <source>There is opened view with destination file.
Close it or choose different file</source>
        <translation>Hedef dosya ile açık görünüm var.
Kapatın veya farklı bir dosya seçin</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="341"/>
        <source>Destination folder &apos;%1&apos; is not writable, please choose different destination URL</source>
        <translation>Hedef klasör &apos;%1&apos; yazılabilir değil, lütfen farklı bir hedef URL seçin</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="347"/>
        <source>Destination file already exists.
To overwrite the file, press &apos;Replace&apos;.
To append data to existing file press &apos;Append&apos;.</source>
        <translation>Hedef dosya zaten var.
Dosyanın üzerine yazmak için &apos;Değiştir&apos;e basın.
Mevcut dosyaya veri eklemek için &apos;Ekle&apos;ye basın.</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="350"/>
        <source>Replace</source>
        <translation>Yer değiştir</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="351"/>
        <source>Append</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="352"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="358"/>
        <source>Destination file &apos;%1&apos; cannot be removed</source>
        <translation>Hedef dosya &apos;%1&apos; kaldırılamaz</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="381"/>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="384"/>
        <source>Destination UGENEDB File</source>
        <translation>Hedef UGENEDB Dosyası</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="381"/>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="384"/>
        <source>UGENEDB Files (*.ugenedb);;All Files (*)</source>
        <translation>UGENEDB Dosyaları (*.ugenedb);;Tüm Dosyalar (*)</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="88"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="103"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="117"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="132"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="166"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="182"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="196"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="229"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="236"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="243"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="250"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="275"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="283"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="291"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="299"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="355"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="364"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="411"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="418"/>
        <source>The iteration has no next element</source>
        <translation>Yinelemenin sonraki öğesi yok</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="348"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="631"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="644"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="691"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="738"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="765"/>
        <source>Task was cancelled</source>
        <translation>Görev iptal edildi</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="50"/>
        <location filename="../src/Dbi.cpp" line="123"/>
        <location filename="../src/Dbi.cpp" line="145"/>
        <location filename="../src/Dbi.cpp" line="370"/>
        <location filename="../src/Dbi.cpp" line="388"/>
        <location filename="../src/Dbi.cpp" line="414"/>
        <location filename="../src/Dbi.cpp" line="433"/>
        <location filename="../src/Dbi.cpp" line="445"/>
        <location filename="../src/Dbi.cpp" line="457"/>
        <location filename="../src/Dbi.cpp" line="472"/>
        <location filename="../src/Dbi.cpp" line="487"/>
        <location filename="../src/Dbi.cpp" line="503"/>
        <location filename="../src/Dbi.cpp" line="515"/>
        <location filename="../src/Dbi.cpp" line="530"/>
        <location filename="../src/Dbi.cpp" line="568"/>
        <location filename="../src/Dbi.cpp" line="588"/>
        <location filename="../src/Dbi.cpp" line="616"/>
        <location filename="../src/Dbi.cpp" line="657"/>
        <location filename="../src/Dbi.cpp" line="690"/>
        <location filename="../src/Dbi.cpp" line="718"/>
        <location filename="../src/Dbi.cpp" line="765"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="72"/>
        <source>Invalid DBI state</source>
        <translation>Geçersiz DBI durumu</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="54"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="76"/>
        <source>URL is not specified</source>
        <translation>URL belirtilmedi</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="58"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="80"/>
        <source>Non-local files are not supported</source>
        <translation>Yerel olmayan dosyalar desteklenmez</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="65"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="114"/>
        <source>Can&apos;t open file &apos;%1&apos;</source>
        <translation>&apos;%1&apos; dosyası açılamıyor</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="76"/>
        <source>Can&apos;t open index database</source>
        <translation>Dizin veritabanını açamıyorum</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="294"/>
        <source>Operation was cancelled</source>
        <translation>İşlem iptal edildi</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="460"/>
        <location filename="../src/Dbi.cpp" line="475"/>
        <location filename="../src/Dbi.cpp" line="518"/>
        <location filename="../src/Dbi.cpp" line="533"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="296"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="306"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="334"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="344"/>
        <source>No such folder: %1</source>
        <translation>Böyle bir klasör yok: %1</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="571"/>
        <location filename="../src/Dbi.cpp" line="591"/>
        <location filename="../src/Dbi.cpp" line="619"/>
        <location filename="../src/Dbi.cpp" line="693"/>
        <location filename="../src/Dbi.cpp" line="721"/>
        <location filename="../src/Dbi.cpp" line="768"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="561"/>
        <source>The specified object is not an assembly</source>
        <translation>Belirtilen nesne bir montaj değil</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="660"/>
        <source>The specified object is not an assembly read</source>
        <translation>Belirtilen nesne bir derleme okuması değil</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="84"/>
        <location filename="../src/SamReader.cpp" line="122"/>
        <source>Invalid read position: %1</source>
        <translation>Geçersiz okuma konumu: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="145"/>
        <source>Invalid mate reference id: %1</source>
        <translation>Geçersiz eş referans kimliği: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="153"/>
        <location filename="../src/SamReader.cpp" line="214"/>
        <source>Invalid mate position: %1</source>
        <translation>Geçersiz montaj ilişkisi konumu: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="161"/>
        <source>Invalid template length of a sigle-fragment template: %1</source>
        <translation>Tek parçalı bir şablon için geçersiz şablon uzunluğu: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="202"/>
        <location filename="../src/SamReader.cpp" line="181"/>
        <source>Invalid cigar operation code: %1</source>
        <translation>Geçersiz puro işlem kodu: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="323"/>
        <source>Invalid block size: %1</source>
        <translation>Geçersiz blok boyutu: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="327"/>
        <source>Invalid reference id: %1</source>
        <translation>Geçersiz referans kimliği: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="440"/>
        <source>Invalid header text size: %1</source>
        <translation>Geçersiz başlık metin boyutu: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="455"/>
        <source>Invalid reference name length: %1</source>
        <translation>Geçersiz referans adı uzunluğu: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="460"/>
        <location filename="../src/SamReader.cpp" line="104"/>
        <source>Invalid reference name: %1</source>
        <translation>Geçersiz referans adı: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="465"/>
        <source>Invalid reference sequence length: %1</source>
        <translation>Geçersiz referans sıra uzunluğu: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="483"/>
        <source>Invalid header line: %1</source>
        <translation>Geçersiz başlık satırı: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="491"/>
        <location filename="../src/SamReader.cpp" line="343"/>
        <source>Invalid header record tag: %1</source>
        <translation>Geçersiz başlık kayıt etiketi: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="504"/>
        <location filename="../src/SamReader.cpp" line="356"/>
        <source>Invalid header field: %1</source>
        <translation>Geçersiz başlık alanı: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="508"/>
        <location filename="../src/SamReader.cpp" line="360"/>
        <source>Invalid header field tag: %1</source>
        <translation>Geçersiz başlık alanı etiketi: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="512"/>
        <location filename="../src/SamReader.cpp" line="364"/>
        <source>Invalid %1-%2 value: %3</source>
        <translation>Geçersiz%1-%2 değeri: %3</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="517"/>
        <location filename="../src/SamReader.cpp" line="369"/>
        <source>Duplicate header field: %1</source>
        <translation>Yinelenen başlık alanı: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="530"/>
        <location filename="../src/SamReader.cpp" line="382"/>
        <source>HD record without VN field</source>
        <translation>VN alanı olmadan HD kaydı</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="545"/>
        <location filename="../src/SamReader.cpp" line="397"/>
        <source>Invalid HD-SO value: %1</source>
        <translation>Geçersiz HD-SO değeri: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="555"/>
        <source>Unmatched SQ-SN value: %1</source>
        <translation>Eşleşmeyen SQ-SN değeri: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="558"/>
        <location filename="../src/SamReader.cpp" line="408"/>
        <source>SQ record without SN field</source>
        <translation>SN alanı olmadan SQ kaydı</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="566"/>
        <source>SQ-LN value mismatch: %1 != %2</source>
        <translation>SQ-LN değer uyuşmazlığı: %1 != %2</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="569"/>
        <location filename="../src/SamReader.cpp" line="420"/>
        <source>Invalid SQ-LN value: %1</source>
        <translation>Geçersiz SQ-LN değeri: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="572"/>
        <location filename="../src/SamReader.cpp" line="423"/>
        <source>SQ record without LN field</source>
        <translation>LN alanı olmadan SQ kaydı</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="581"/>
        <location filename="../src/SamReader.cpp" line="433"/>
        <source>Invalid SQ-M5 value: %1</source>
        <translation>Geçersiz SQ-M5 değeri: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="633"/>
        <location filename="../src/SamReader.cpp" line="485"/>
        <source>Invalid RG-PI field value: %1</source>
        <translation>Geçersiz RG-PI alan değeri: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="675"/>
        <location filename="../src/SamReader.cpp" line="527"/>
        <source>Invalid PG-PP field value: %1</source>
        <translation>Geçersiz PG-PP alan değeri: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="40"/>
        <source>Unexpected empty string</source>
        <translation>Beklenmeyen boş dize</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="47"/>
        <source>Not enough fields in one of alignments</source>
        <translation>Hizalamalardan birinde yeterli alan yok</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="54"/>
        <source>Invalid query template name: %1</source>
        <translation>Geçersiz sorgu şablonu adı: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="62"/>
        <source>Invalid FLAG value: %1</source>
        <translation>Geçersiz BAYRAK değeri: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="110"/>
        <source>Undefined reference name: %1</source>
        <translation>Tanımlanmamış referans adı: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="119"/>
        <source>Invalid read position value: %1</source>
        <translation>Geçersiz okuma konumu değeri: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="130"/>
        <source>Invalid mapping quality value: %1</source>
        <translation>Geçersiz eşleme kalitesi değeri: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="133"/>
        <source>Invalid mapping quality: %1</source>
        <translation>Geçersiz eşleme kalitesi: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="140"/>
        <location filename="../src/SamReader.cpp" line="146"/>
        <source>Invalid cigar value: %1</source>
        <translation>Geçersiz puro değeri: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="193"/>
        <source>Invalid mate reference name: %1</source>
        <translation>Geçersiz eş referans adı: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="201"/>
        <source>Undefined mate reference name: %1</source>
        <translation>Tanımlanmamış montaj ilişkisi referans adı: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="211"/>
        <source>Invalid mate position value: %1</source>
        <translation>Geçersiz montaj ilişkisi değeri: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="222"/>
        <source>Invalid template length value: %1</source>
        <translation>Geçersiz şablon uzunluğu değeri: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="226"/>
        <source>Invalid template length of a single-fragment template: %1</source>
        <translation>Tek parçalı bir şablon için geçersiz şablon uzunluğu: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="234"/>
        <source>Invalid sequence: %1</source>
        <translation>Geçersiz sıra: %1</translation>
    </message>
    <message>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="90"/>
        <source>Can&apos;t build index for: %1</source>
        <translation>%1 için dizin oluşturulamıyor</translation>
    </message>
    <message>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="124"/>
        <source>Can&apos;t load index file for &apos;%1&apos;</source>
        <translation>&apos;%1&apos; için dizin dosyası yüklenemiyor</translation>
    </message>
    <message>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="129"/>
        <source>Can&apos;t read header from file &apos;%1&apos;</source>
        <translation>&apos;%1&apos; dosyasından başlık okunamıyor</translation>
    </message>
    <message>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="234"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="246"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="253"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="265"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="281"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="287"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="293"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="303"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="313"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="324"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="331"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="341"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="555"/>
        <source>Invalid samtools DBI state</source>
        <translation>Geçersiz samtools DBI durumu</translation>
    </message>
    <message>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="255"/>
        <source>Object not found</source>
        <translation>Nesne bulunamadı</translation>
    </message>
    <message>
        <source>Please select the file with the reference sequence</source>
        <translation>Lütfen referans sırasına sahip dosyayı seçin</translation>
    </message>
</context>
<context>
    <name>U2::BAM::BAMImporter</name>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="85"/>
        <source>BAM/SAM file import</source>
        <translation>BAM / SAM dosyası içe aktar</translation>
    </message>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="96"/>
        <source>BAM files importer is used to convert conventional BAM and SAM files into UGENE database format. Having BAM or SAM file converted into UGENE DB format you get an fast and efficient interface to your data with an option to change the content</source>
        <translation>BAM dosyalarını içe aktarıcı, geleneksel BAM ve SAM dosyalarını UGENE veritabanı biçimine dönüştürmek için kullanılır. BAM veya SAM dosyasının UGENE DB formatına dönüştürülmesiyle, içeriği değiştirme seçeneği ile verileriniz için hızlı ve verimli bir arayüz elde edersiniz</translation>
    </message>
</context>
<context>
    <name>U2::BAM::BAMImporterTask</name>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="125"/>
        <source>BAM/SAM file import: %1</source>
        <translation>BAM / SAM dosyası içe aktarma: %1</translation>
    </message>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="234"/>
        <source>Can&apos;t create a temporary database</source>
        <translation>Geçici bir veritabanı oluşturamıyorum</translation>
    </message>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="257"/>
        <source>SAM cannot be converted to BAM: neither reference nor header in SAM file is present</source>
        <translation>SAM, BAM&apos;a dönüştürülemiyor: SAM dosyasında ne referans ne de başlık mevcut</translation>
    </message>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="305"/>
        <source>Failed to get load task for : %1</source>
        <translation>%1 için yükleme görevi alınamadı</translation>
    </message>
</context>
<context>
    <name>U2::BAM::ConvertToSQLiteDialog</name>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="53"/>
        <source>Import</source>
        <translation>İçeri aktar</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="57"/>
        <source>Import SAM File</source>
        <translation>SAM Dosyasını İçe Aktar</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="59"/>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="61"/>
        <source>Import BAM File</source>
        <translation>BAM Dosyasını İçe Aktar</translation>
    </message>
</context>
<context>
    <name>U2::BAM::ConvertToSQLiteTask</name>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="53"/>
        <source>Convert BAM to UGENE database (%1)</source>
        <translation>BAM&apos;yi UGENE veritabanına dönüştür (%1)</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="439"/>
        <source>Converting assembly from %1 to %2 started</source>
        <translation>Derleme %1&apos;den %2&apos;ye dönüştürülmeye başlandı</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="474"/>
        <source>Converting assembly from %1 to %2 cancelled</source>
        <translation>Derlemeyi %1&apos;den %2&apos;ye dönüştürme iptal edildi</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="480"/>
        <source>Converting assembly from %1 to %2 failed: %3</source>
        <translation>Derleme %1&apos;den %2&apos;ye dönüştürülemedi: %3</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="549"/>
        <source>Packing reads for assembly &apos;%1&apos; (%2 of %3)</source>
        <translation>Ambalaj &apos;%1&apos; derlemesi için okur (%2 / %3)</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="613"/>
        <source>Importing assembly &apos;%1&apos; (%2 of %3)</source>
        <translation>&apos;%1&apos; derlemesi içe aktarılıyor (%2 / %3)</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="634"/>
        <source>Successfully imported %1 reads for assembly &apos;%2&apos; (total %3 reads imported)</source>
        <translation>&apos;%2&apos; derlemesi için %1 okuma başarıyla içe aktarıldı (toplam %3 okuma içe aktarıldı)</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="654"/>
        <source>Importing unmapped reads</source>
        <translation>Eşlenmemiş okumaları içe aktarma</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="697"/>
        <source>No bam index given, preparing sequential import</source>
        <translation>Hiçbir bam indeksi verilmedi, sıralı içe aktarma hazırlanıyor</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="709"/>
        <source>Importing reads sequentially</source>
        <translation>Okumaları sırayla içe aktarma</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="864"/>
        <source>Warning: incorrect maxProw == %1, probably packing was not done! Attribute was not set</source>
        <translation>Uyarı: yanlış maxProw == %1, muhtemelen paketleme yapılmadı! Öznitelik ayarlanmadı</translation>
    </message>
</context>
<context>
    <name>U2::BAM::LoadInfoTask</name>
    <message>
        <location filename="../src/LoadBamInfoTask.cpp" line="39"/>
        <source>Load BAM info</source>
        <translation>BAM bilgilerini yükle</translation>
    </message>
    <message>
        <location filename="../src/LoadBamInfoTask.cpp" line="63"/>
        <source>Can&apos;t open file &apos;%1&apos;</source>
        <translation>&apos;%1&apos; dosyası açılamıyor</translation>
    </message>
    <message>
        <location filename="../src/LoadBamInfoTask.cpp" line="94"/>
        <source>Loading BAM info for file &apos;%1&apos; failed: %2</source>
        <translation>&apos;%1&apos; dosyası için BAM bilgisi yüklenemedi: %2</translation>
    </message>
    <message>
        <location filename="../src/PrepareToImportTask.cpp" line="68"/>
        <source>Can not copy the &apos;%1&apos; file to &apos;%2&apos;</source>
        <translation>&apos;%1&apos; dosyası &apos;%2&apos; klasörüne kopyalanamıyor</translation>
    </message>
    <message>
        <location filename="../src/PrepareToImportTask.cpp" line="91"/>
        <source>Converting SAM to BAM</source>
        <translation>SAM’i BAM’a dönüştürme</translation>
    </message>
    <message>
        <location filename="../src/PrepareToImportTask.cpp" line="111"/>
        <source>Sorting BAM</source>
        <translation>BAM sıralama</translation>
    </message>
    <message>
        <location filename="../src/PrepareToImportTask.cpp" line="128"/>
        <source>Coping sorted BAM</source>
        <translation>Tasnif edilmiş BAM</translation>
    </message>
    <message>
        <location filename="../src/PrepareToImportTask.cpp" line="133"/>
        <source>Creating BAM index</source>
        <translation>BAM dizini oluşturma</translation>
    </message>
    <message>
        <location filename="../src/PrepareToImportTask.cpp" line="171"/>
        <source>Unknown reference sequence format. Only FASTA is supported</source>
        <translation>Bilinmeyen referans dizisi biçimi. Yalnızca FAŞTA desteklenmektedir</translation>
    </message>
    <message>
        <location filename="../src/PrepareToImportTask.cpp" line="176"/>
        <source>The detected reference sequence format is &apos;%1&apos;. Only FASTA is supported</source>
        <translation>Saptanan referans dizisi biçimi &apos;%1&apos;. Yalnızca FAŞTA desteklenmektedir</translation>
    </message>
</context>
<context>
    <name>U2::BAMFormat</name>
    <message>
        <location filename="../src/BAMFormat.cpp" line="52"/>
        <source>BAM File</source>
        <translation>BAM Dosyası</translation>
    </message>
</context>
</TS>
